Overview
=========

.. raw:: html
   
   <h1 style="text-align: center">
      <img src="../_static/logo.png" alt="qbraid logo" style="width:50px;height:50px;">
      <span> qBraid</span>
      <span style="color:#808080"> | Lab</span>
   </h1>
   <p style="text-align:center;font-style:italic;color:#808080">
      A web-based IDE optimized for quantum computing.
   </p>


`qBraid Lab <https://lab.qbraid.com>`_ is a web-based IDE cross JupyterLab interface that provides
software tools for researchers and developers in quantum, as well as access to quantum hardware.

- `Account <account.html>`_
   - `Add access key <account.html#add-access-key>`_

- `Environments <environments.html>`_
   - `Install environment <environments.html#install-environment>`_
   - `Create environment <environments.html#create-environment>`_
   - `Install new package <environments.html#install-new-package>`_

- `File Browser  <files.html>`_
   - `Open files <files.html#open-files>`_

- `Notebooks <notebooks.html>`_
   - `Add/remove kernels <notebooks.html#add-remove-kernels>`_
   - `Create notebook <notebooks.html#create-notebook>`_
   - `Switch notebook kernel <notebooks.html#switch-notebook-kernel>`_
   - `Share noteboook <notebooks.html#share-notebook>`_

- `Quantum Jobs <quantumjobs.html>`_
   - `Credits <quantumjobs.html#credits>`_
   - `Which environments? <quantumjobs.html#which-environments>`_
   - `Enable/disable <quantumjobs.html#enable-disable>`_
   - `Manage <quantumjobs.html#manage>`_

- `Integrations <integrations.html>`_
   - `Visual Studio Code <integrations.html#visual-studio-code>`_

- `System Info <system.html>`_
   - `Operating System <system.html#operating-system>`_
   - `Pre-Installed Software <system.html#gnu-packages>`_

- `Troubleshooting <troubleshoot.html>`_
   - `Error launching Lab <troubleshoot.html#error-launching-lab>`_
   - `Lab server errors <troubleshoot.html#lab-server-errors>`_
   - `ModuleNotFoundError <troubleshoot.html#modulenotfounderror>`_
   - `NoRegionError <troubleshoot.html#noregionerror>`_
   - `Extension sidebar errors <troubleshoot.html#extension-sidebar-errors>`_


.. seealso::
   
   - `Project Jupyter <https://docs.jupyter.org/en/latest/#jupyter-project-documentation>`_
   - `JupyterLab <https://jupyterlab.readthedocs.io/en/stable/>`_
   - `Jupyter Notebook <https://jupyter-notebook.readthedocs.io/en/latest/notebook.html>`_
